﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Controls.Grids.Primitives;
using Infragistics.Controls.Grids;
using Infragistics.Windows;

namespace AddRowOnEnterOnly
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        bool canAdd = false;
        bool escape = false;

        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = Data.GetData(10, 20, 30);
        }

        private void XamGrid_CellExitingEditMode(object sender, Infragistics.Controls.Grids.ExitEditingCellEventArgs e)
        {
            if (e.Cell.Row is AddNewRow)
            {
                if (!canAdd)
                {
                    e.Cancel = true;
                }
                if (escape)
                {
                    e.Cell.Column.ColumnLayout.Grid.CellExitingEditMode -= XamGrid_CellExitingEditMode;
                    e.Cell.Column.ColumnLayout.Grid.ExitEditMode(true);
                    e.Cell.Column.ColumnLayout.Grid.CellExitingEditMode += XamGrid_CellExitingEditMode;
                }

                canAdd = false;
                escape = false;
            }

        }

        private void XamGrid_CellControlAttached(object sender, Infragistics.Controls.Grids.CellControlAttachedEventArgs e)
        {
            if (e.Cell.Row is AddNewRow)
            {
                e.Cell.Control.KeyDown += new KeyEventHandler(Control_KeyDown);
            }
        }

        void Control_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Enter)
            {
                canAdd = true;
            }

            if (e.Key == Key.Escape)
            {
                escape = true;
            }
        }

        void Control_PreviewKeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Enter)
            {
                canAdd = true;
                xamGrid1.ExitEditMode(false);
            }

            if (e.Key == Key.Escape)
            {
                escape = true;
            }
        }

        private void XamGrid_Loaded(object sender, RoutedEventArgs e)
        {
            AddNewRow addRow = ((sender as XamGrid).Rows[0].Manager as RowsManager).AddNewRowTop;

            (sender as XamGrid).EnterEditMode(addRow);
        }
    }

    public class Data : INotifyPropertyChanged
    {
        private int open;
        private int close;
        private int high;
        private int low;
        private int value;
        private string label;

        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Open
        {
            get { return open; }
            set
            {
                open = value;
                PropChanged("Open");
            }
        }

        public int Close
        {
            get { return close; }
            set
            {
                close = value;
                PropChanged("Close");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public int Low
        {
            get { return low; }
            set
            {
                low = value;
                PropChanged("Low");
            }
        }

        public int Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }


        private DateTime date;

        public DateTime Date
        {
            get { return date; }
            set { date = value; PropChanged("Date"); }
        }


        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Label = "Item " + i,
                    Date = DateTime.Now.AddDays(i),
                    Open = r.Next(rangeStart, rangeEnd),
                    Close = r.Next(2),
                    High = r.Next(rangeStart, rangeEnd),
                    Low = r.Next(rangeStart, rangeEnd),
                    Value = r.Next(rangeStart, rangeEnd),
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }

    public class ComboData : ObservableCollection<Data>
    {
        public ComboData()
        {
            Add(new Data { Label = "Item 1", Open = 1 });
            Add(new Data { Label = "Item 2", Open = 2 });
            Add(new Data { Label = "Item 3", Open = 3 });
        }
    }
}